==> openafs-1.2.3-src.tar.gz: openafs-1.2.3/src/WINNT/client_creds/resource.h <==
/*
 * Copyright 2000, International Business Machines Corporation and others.
 * All Rights Reserved.
 * 
 * This software has been released under the terms of the IBM Public
 * License.  For details, see the LICENSE file in the top-level source
 * directory or online at http://www.openafs.org/dl/license10.html
 */

#define IDS_TOOLTIP                     1
#define IDS_CREDENTIALS                 2
#define IDS_UNKNOWN                     3
#define IDS_ADVANCED                    4
#define IDS_CREDS                       5
#define IDS_NO_CREDS                    6
#define IDS_SERVICE_BROKEN              9
#define IDS_SERVICE_RUNNING             10
#define IDS_SERVICE_STOPPED             11
#define IDS_SERVICE_STOPPING            12
#define IDS_SERVICE_STARTING            13
#define IDS_SERVICE_UNKNOWN             14
#define IDS_SERVICE_FAIL_STOP           15
#define IDS_SERVICE_FAIL_START          16
#define IDS_SERVICE_FAIL_CONFIG         17
#define IDS_SERVICE_ERROR               18
#define IDS_ERROR_TITLE                 19
#define IDS_ERROR_DESTROY_NOCM          20
#define IDS_ERROR_DESTROY_UNKNOWN       21
#define IDS_ERROR_OBTAIN                22
#define IDS_TITLE_VERSION               23
#define IDS_TITLE_VERSION_NOPATCH       24
#define IDS_MOUNT_SOME                  25
#define IDS_MOUNT_NONE                  26
#define IDS_MOUNT                       27
#define IDS_WIZ_NEXT                    28
#define IDS_WIZ_FINISH                  29
#define IDS_MAP_LETTER                  30
#define IDS_DRIVE_MAP                   31
#define IDS_ERROR_MAP                   32
#define IDS_ERROR_MAP_DESC              33
#define IDS_ERROR_UNMAP                 34
#define IDS_ERROR_UNMAP_DESC            35
#define IDS_CELL_GATEWAY                36
#define IDS_BADMAP_TITLE                37
#define IDS_BADMAP_DESC                 38
#define IDS_UNCONFIG_TITLE              39
#define IDS_UNCONFIG_DESC               40
#define IDS_NEWSUB_TITLE                41
#define IDS_NEWSUB_DESC                 42
#define IDS_BADSUB_TITLE                43
#define IDS_BADSUB_DESC                 44
#define IDS_TITLE_95                    45
#define IDS_TOOLTIP_95                  46
#define IDS_ERROR_TITLE_95              48
#define IDS_ERROR_DESTROY_95            49
#define IDS_ERROR_OBTAIN_95             50
#define IDS_UNCONFIG_TITLE_95           51
#define IDS_UNCONFIG_DESC_95            52
#define IDS_NEWSUB_TITLE_95             53
#define IDS_BADSUB_TITLE_95             54
#define IDI_MAIN                        100
#define IDD_MAIN                        101
#define IDD_TAB_CREDS                   102
#define IDD_TAB_NOCREDS                 103
#define MENU_TRAYICON                   104
#define IDD_TAB_ADVANCED                104
#define IDI_CREDS_NO                    105
#define IDI_CREDS_SOME                  106
#define IDI_CREDS_YES                   107
#define IDD_NEWCREDS                    108
#define IDD_NEWCREDS_EXPIRE             109
#define IDD_TAB_MOUNT                   110
#define IDD_WIZARD                      111
#define IDD_WIZ_START                   112
#define IDB_WIZ16                       112
#define IDD_WIZ_CREDS                   113
#define IDB_WIZ256                      113
#define IDD_WIZ_STARTING                114
#define IDD_WIZ_MOUNT                   115
#define IDD_TERMINATE                   116
#define IDD_TERMINATE_SMALL             117
#define IDD_WIZ_MOUNTING                118
#define IDD_WIZ_FINISH                  119
#define IDD_MAPPING                     120
#define IDD_TERMINATE_SMALL_95          121
#define M_TERMINATE                     3000
#define M_ACTIVATE                      3001
#define M_REMIND                        3002
#define M_TERMINATE_NOW                 3003
#define IDC_TITLE_AFS                   5000
#define IDC_TITLE_VERSION               5001
#define IDC_TITLE_NT                    5002
#define IDC_TABS                        5003
#define IDC_CREDS_CELL                  5004
#define IDC_CREDS_INFO                  5005
#define IDC_CREDS_REMIND                5006
#define IDC_CREDS_DESTROY               5007
#define IDC_CREDS_OBTAIN                5008
#define IDC_SERVICE_STATUS              5009
#define IDC_SERVICE_AUTO                5011
#define IDC_SERVICE_LOGIN               5012
#define IDC_SERVICE_START               5013
#define IDC_SERVICE_STOP                5014
#define IDC_NEWCREDS_CELL               5014
#define IDC_OPEN_CPL                    5015
#define IDC_NEWCREDS_USER               5015
#define IDC_NEWCREDS_PASSWORD           5016
#define IDC_NEWCREDS_TITLE              5017
#define IDC_LIST                        5019
#define IDC_TITLE                       5020
#define IDC_REMOVE                      5021
#define IDC_EDIT                        5022
#define IDC_STARTUP                     5022
#define IDC_ADD                         5023
#define IDC_LHS                         5024
#define IDC_RHS                         5025
#define IDC_NOCREDS                     5026
#define IDC_YESCREDS                    5027
#define IDC_START_FAIL                  5029
#define IDC_START_TRY                   5030
#define IDC_NOMAP                       5031
#define IDNEXT                          5032
#define IDBACK                          5034
#define IDC_YESMAP                      5035
#define IDC_MAP_LETTER                  5036
#define IDC_MAP_PATH                    5037
#define IDC_LEAVE                       5038
#define IDC_MAP_DESC                    5038
#define IDC_STOP                        5039
#define IDC_MAP_FAIL                    5045
#define IDC_MAP_TRY                     5046
#define IDC_MAP_FINISH                  5047
#define IDC_MAP_PERSISTENT              5049
#define IDC_RUNNING                     5050
#define IDC_STOPPED                     5051
#define IDC_STATIC                      -1

// Next default values for new objects
// 
#ifdef APSTUDIO_INVOKED
#ifndef APSTUDIO_READONLY_SYMBOLS
#define _APS_NO_MFC                     1
#define _APS_3D_CONTROLS                     1
#define _APS_NEXT_RESOURCE_VALUE        122
#define _APS_NEXT_COMMAND_VALUE         3004
#define _APS_NEXT_CONTROL_VALUE         5053
#define _APS_NEXT_SYMED_VALUE           7000
#endif
#endif

==> openafs-1.4.0-rc3-src.tar.gz: openafs-1.4.0-rc3/src/WINNT/client_creds/resource.h <==
/*
 * Copyright 2000, International Business Machines Corporation and others.
 * All Rights Reserved.
 * 
 * This software has been released under the terms of the IBM Public
 * License.  For details, see the LICENSE file in the top-level source
 * directory or online at http://www.openafs.org/dl/license10.html
 */

#define IDS_TOOLTIP                            0
#define IDS_TOOLTIP_95                         1
#define IDS_CREDENTIALS                        2
#define IDS_UNKNOWN                            3
#define IDS_ADVANCED                           4
#define IDS_CREDS                              5
#define IDS_NO_CREDS                           6
#define IDS_SERVICE_BROKEN                     7
#define IDS_SERVICE_RUNNING                    8
#define IDS_SERVICE_STOPPED                    9
#define IDS_SERVICE_STOPPING                  10
#define IDS_SERVICE_STARTING                  11
#define IDS_SERVICE_UNKNOWN                   12
#define IDS_SERVICE_FAIL_STOP                 13
#define IDS_SERVICE_FAIL_START                14
#define IDS_SERVICE_FAIL_CONFIG               15
#define IDS_SERVICE_ERROR                     16
#define IDS_ERROR_TITLE                       17
#define IDS_ERROR_TITLE_95                    18
#define IDS_ERROR_DESTROY_95                  19
#define IDS_ERROR_DESTROY_NOCM                20
#define IDS_ERROR_DESTROY_UNKNOWN             21
#define IDS_ERROR_OBTAIN                      22
#define IDS_ERROR_OBTAIN_95                   23
#define IDS_TITLE_VERSION                     24
#define IDS_TITLE_VERSION_NOPATCH             25
#define IDS_MOUNT_SOME                        26
#define IDS_MOUNT_NONE                        27
#define IDS_MOUNT                             28
#define IDS_WIZ_NEXT                          29
#define IDS_WIZ_FINISH                        30
#define IDS_MAP_LETTER                        31
#define IDS_DRIVE_MAP                         32
#define IDS_ERROR_MAP                         33
#define IDS_ERROR_MAP_DESC                    34
#define IDS_ERROR_UNMAP                       35
#define IDS_ERROR_UNMAP_DESC                  36
#define IDS_CELL_GATEWAY                      37
#define IDS_BADMAP_TITLE                      38
#define IDS_BADMAP_DESC                       39
#define IDS_UNCONFIG_TITLE_95                 40
#define IDS_UNCONFIG_DESC_95                  41
#define IDS_UNCONFIG_TITLE                    42
#define IDS_UNCONFIG_DESC                     43
#define IDS_NEWSUB_TITLE                      44
#define IDS_NEWSUB_TITLE_95                   45
#define IDS_NEWSUB_DESC                       46
#define IDS_BADSUB_TITLE                      47
#define IDS_BADSUB_TITLE_95                   48
#define IDS_BADSUB_DESC                       49
#define IDS_TITLE_95                          50
#define IDS_CREDS_EXPIRED                     51

#define IDI_MAIN                        100
#define IDD_MAIN                        101
#define IDD_TAB_CREDS                   102
#define IDD_TAB_NOCREDS                 103
#define MENU_TRAYICON                   104
#define IDD_TAB_ADVANCED                104
#define IDI_CREDS_NO                    105
#define IDI_CREDS_SOME                  106
#define IDI_CREDS_YES                   107
#define IDD_NEWCREDS                    108
#define IDD_NEWCREDS_EXPIRE             109
#define IDD_TAB_MOUNT                   110
#define IDD_WIZARD                      111
#define IDD_WIZ_START                   112
#define IDB_WIZ16                       112
#define IDD_WIZ_CREDS                   113
#define IDB_WIZ256                      113
#define IDD_WIZ_STARTING                114
#define IDD_WIZ_MOUNT                   115
#define IDD_TERMINATE                   116
#define IDD_TERMINATE_SMALL             117
#define IDD_WIZ_MOUNTING                118
#define IDD_WIZ_FINISH                  119
#define IDD_MAPPING                     120
#define IDD_TERMINATE_SMALL_95          121
#define IDD_AUTH                        122
#define M_TERMINATE                     3000
#define M_ACTIVATE                      3001
#define M_REMIND                        3002
#define M_TERMINATE_NOW                 3003
#define IDC_TITLE_AFS                   5000
#define IDC_TITLE_VERSION               5001
#define IDC_TITLE_NT                    5002
#define IDC_TABS                        5003
#define IDC_CREDS_CELL                  5004
#define IDC_CREDS_INFO                  5005
#define IDC_CREDS_REMIND                5006
#define IDC_CREDS_DESTROY               5007
#define IDC_CREDS_OBTAIN                5008
#define IDC_SERVICE_STATUS              5009
#define IDC_SERVICE_AUTO                5011
#define IDC_SERVICE_LOGIN               5012
#define IDC_SERVICE_START               5013
#define IDC_SERVICE_STOP                5014
#define IDC_NEWCREDS_CELL               5014
#define IDC_OPEN_CPL                    5015
#define IDC_NEWCREDS_USER               5015
#define IDC_NEWCREDS_PASSWORD           5016
#define IDC_NEWCREDS_TITLE              5017
#define IDC_LIST                        5019
#define IDC_TITLE                       5020
#define IDC_REMOVE                      5021
#define IDC_EDIT                        5022
#define IDC_STARTUP                     5022
#define IDC_ADD                         5023
#define IDC_LHS                         5024
#define IDC_RHS                         5025
#define IDC_NOCREDS                     5026
#define IDC_YESCREDS                    5027
#define IDC_START_FAIL                  5029
#define IDC_START_TRY                   5030
#define IDC_NOMAP                       5031
#define IDNEXT                          5032
#define IDBACK                          5034
#define IDC_YESMAP                      5035
#define IDC_MAP_LETTER                  5036
#define IDC_MAP_PATH                    5037
#define IDC_LEAVE                       5038
#define IDC_MAP_DESC                    5038
#define IDC_STOP                        5039
#define IDC_MAP_FAIL                    5045
#define IDC_MAP_TRY                     5046
#define IDC_MAP_FINISH                  5047
#define IDC_MAP_PERSISTENT              5049
#define IDC_RUNNING                     5050
#define IDC_STOPPED                     5051
#define IDC_STATICSUBMOUNT              5052
#define IDC_STATIC                      -1

// Next default values for new objects
// 
#ifdef APSTUDIO_INVOKED
#ifndef APSTUDIO_READONLY_SYMBOLS
#define _APS_NO_MFC                     1
#define _APS_3D_CONTROLS                     1
#define _APS_NEXT_RESOURCE_VALUE        122
#define _APS_NEXT_COMMAND_VALUE         3004
#define _APS_NEXT_CONTROL_VALUE         5053
#define _APS_NEXT_SYMED_VALUE           7000
#endif
#endif
